@@ -1,16 +1,12 @@
 import os
 
-
-def main():
-    pass
-
-
 def list_files(folder_path):
     list_of_files = list()
     for (dirpath, dirnames, filenames) in os.walk(folder_path):
         list_of_files += [os.path.join(dirpath, file) for file in filenames]
     return list_of_files
 
+
 def setup_path(folder_path):
     if not os.path.exists(folder_path):
         try:
@@ -19,9 +15,4 @@ def setup_path(folder_path):
             logging.info('failed to create {}'.format(folder_path))
         else:
             logging.info('created directory(s) {}'.format(folder_path))
-    return folder_path
-
-
-
-if __name__ == "__main__":
-    main()
\ No newline at end of file
+    return folder_path
\ No newline at end of file
